@@ -73,8 +73,8 @@ fi
 # allow overriding the normaliz version via env var or argument, so that
 # we can test with many different ones
 if [ -z $NORMALIZ_VERSION ]; then
-    NORMALIZ_VERSION=3.5.4
-    NORMALIZ_SHA256=d65739c43726733f3bb30842442296bfe832eef238935e8729beaebbed231656
+    NORMALIZ_VERSION=3.9.1
+    NORMALIZ_SHA256=ad5dbecc3ca3991bcd7b18774ebe2b68dae12ccca33c813ab29891beb85daa20
 fi
 NORMALIZ_BASE=normaliz-${NORMALIZ_VERSION}
 NORMALIZ_TAR=${NORMALIZ_BASE}.tar.gz
@@ -94,13 +94,6 @@ echo "##"
 rm -rf ${NORMALIZ_BASE}
 tar xvf ${NORMALIZ_TAR}
 
-# The cmake build process honors environment variables like
-# GMP_DIR and BOOST_ROOT. So if you need to tell the build
-# process where to find GMP and Boost, you can invoke this
-# script like this:
-#
-#  GMP_DIR=/some/path BOOST_ROOT=/another/path ./build-normaliz.sh $GAPROOT
-
 echo "##"
 echo "## compiling Normaliz ${NORMALIZ_VERSION}"
 echo "##"
@@ -108,7 +101,7 @@ echo "##"
 # If GAP was build for 32 bit, also do it for normaliz
 if [ x$GAParch_abi = x"32-bit" ] || [ x$GAP_ABI = x32 ]; then
     echo "GAP was built for 32 bit"
-    export CXXFLAGS="-m32"
+    export CXXFLAGS="${CXXFLAGS} -m32"
 fi
 
 NormalizInstallDir=$PWD/NormalizInstallDir
@@ -123,3 +116,13 @@ else
 fi
 make -j4
 make install
+
+osname=$(uname -s)
+if [ "${osname#*CYGWIN}" != "$osname" ]; then
+    echo "##"
+    echo "## Extra Cygwin installation step"
+    echo "##"
+    # We have to move the Normalize dll to $GAPDIR/.libs, as this is the only
+    # place which Cygwin will check for it inside $GAPDIR.
+    cp ${NormalizInstallDir}/bin/cygnormaliz-*.dll "${GAPDIR}/.libs"
+fi
